<template>
    <h3 class="fs-2 fw-bold mb-5">Our Top Categories</h3>
    <swiper :modules="[Navigation, Pagination, Autoplay]" :slides-per-view="5.5" :space-between="20" navigation
        pagination autoplay loop class="category-slider">
        <swiper-slide v-for="(category, index) in featuredCategories" :key="index" class="mb-3">
            <router-link :to="'/courses?category_id=' + category.id"
                class="d-block text-decoration-none text-dark mb-5">
                <div class="category-box p-4">
                    <img :src="category.image" :alt="category.title" class="w-50 mb-3">
                    <h5 class="fs-5 fw-bold fs-6">{{ category.title }}</h5>
                    <span class="d-flex justify-content-between">
                        <small class="text-muted">{{ category.course_count }} Courses</small>
                        <i class="bi bi-chevron-right"></i>
                    </span>
                </div>
            </router-link>
        </swiper-slide>
    </swiper>
</template>

<style lang="scss" scoped>
.category-box {
    border-radius: 15px;
    border: 1px solid #eee;
    transition: all 0.2s ease-out;

    &:hover {
        border-color: #9E4AED;
        border-top-width: 4px;
        box-shadow: 0px 16px 64px 0px #0000000D;
    }
}
</style>

<script setup>
import { Swiper, SwiperSlide } from "swiper/vue"
import { Navigation, Pagination, Autoplay } from "swiper/modules"
import { onMounted, ref } from 'vue'
import axios from 'axios'

let featuredCategories = ref([]);

// Fetch featured categories
const fetchFeaturedCategories = async () => {
    try {
        const response = await axios.get(`/categories`, {
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json'
            },
            params: {
                items_per_page: 20,
                page_number: 1
            }
        });
        featuredCategories.value = response.data.data.categories;
    } catch (error) {
        console.error('Error fetching categories:', error);
    }
};

// Call the function when the component is mounted
onMounted(() => {
    fetchFeaturedCategories();
});
</script>
